Learn R Programming

dndR (version 2.0.0)

spell_text: Retrieve Full Spell Description Text by Spell Name

Description

Accepts user-provided Dungeons & Dragons spell name(s) and returns the full set of spell information and the complete description text. Unlike `dndR::spell_list`, this function requires an exact match between the user-provided spell name(s) and how they appear in the main spell data object. The argument in this function is not sensitive. This function's output differs from `dndR::spell_list` only in that it returns the additional spell description text.

Usage

spell_text(name = NULL)

Value

(dataframe) 11 columns of spell information with one row per spell specified by the user. Returns 12 columns if the spell is a damage-dealing cantrip that deals increased damage as player level increases or if spell can be cast with a higher level spell slot (i.e., "upcast") for an increased effect.

Arguments

name

(character) exact spell name(s) for which to gather description information

Examples

Run this code
spell_text(name = "chill touch")

Run the code above in your browser using DataLab